# Shot-Striper

Add beautiful, striped backgrounds to your screenshots.

![Shot-Striper](https://raw.githubusercontent.com/psyonara/shotstriper/master/imgs/headline.jpg)

## Installation

### Pipx

```shell
pipx install shotstriper
```

### Pip

```shell
pip install shotstriper
```
